[tepl] amtk: testsuite: test-action-map



commit f57a03f1592ab6971b585c9afb9b506dbebd00f3
Author: Sébastien Wilmet <swilmet gnome org>
Date:   Thu Jul 13 16:48:00 2017 +0200

    amtk: testsuite: test-action-map

 testsuite/Makefile.am                  |   12 ++++++++----
 testsuite/{ => amtk}/test-action-map.c |   22 +++++++++++-----------
 2 files changed, 19 insertions(+), 15 deletions(-)
---
diff --git a/testsuite/Makefile.am b/testsuite/Makefile.am
index 497fda6..e2775f3 100644
--- a/testsuite/Makefile.am
+++ b/testsuite/Makefile.am
@@ -25,14 +25,18 @@ noinst_PROGRAMS = $(UNIT_TEST_PROGS)
 TESTS = $(UNIT_TEST_PROGS)
 UNIT_TEST_PROGS =
 
-UNIT_TEST_PROGS += amtk-test-utils
-amtk_test_utils_SOURCES = amtk/test-utils.c
+# Amtk
 
 UNIT_TEST_PROGS += amtk-test-action-info-store
 amtk_test_action_info_store_SOURCES = amtk/test-action-info-store.c
 
-UNIT_TEST_PROGS += test-action-map
-test_action_map_SOURCES = test-action-map.c
+UNIT_TEST_PROGS += amtk-test-action-map
+amtk_test_action_map_SOURCES = amtk/test-action-map.c
+
+UNIT_TEST_PROGS += amtk-test-utils
+amtk_test_utils_SOURCES = amtk/test-utils.c
+
+# Tepl
 
 UNIT_TEST_PROGS += test-buffer-input-stream
 test_buffer_input_stream_SOURCES = test-buffer-input-stream.c
diff --git a/testsuite/test-action-map.c b/testsuite/amtk/test-action-map.c
similarity index 83%
rename from testsuite/test-action-map.c
rename to testsuite/amtk/test-action-map.c
index b4fe182..f47fa9b 100644
--- a/testsuite/test-action-map.c
+++ b/testsuite/amtk/test-action-map.c
@@ -1,14 +1,14 @@
 /*
- * This file is part of Tepl, a text editor library.
+ * This file is part of Amtk - Actions, Menus and Toolbars Kit
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
  * Tepl is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
  * option) any later version.
  *
  * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  * License for more details.
@@ -17,7 +17,7 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <tepl/tepl.h>
+#include <amtk/amtk.h>
 
 static void
 test_add_action_entries_check_dups (void)
@@ -30,7 +30,7 @@ test_add_action_entries_check_dups (void)
        };
 
        group = g_simple_action_group_new ();
-       tepl_action_map_add_action_entries_check_dups (G_ACTION_MAP (group),
+       amtk_action_map_add_action_entries_check_dups (G_ACTION_MAP (group),
                                                       entries,
                                                       G_N_ELEMENTS (entries),
                                                       NULL);
@@ -56,11 +56,11 @@ test_add_action_entries_check_dups__add_two_times (void)
 
        group = g_simple_action_group_new ();
 
-       tepl_action_map_add_action_entries_check_dups (G_ACTION_MAP (group),
+       amtk_action_map_add_action_entries_check_dups (G_ACTION_MAP (group),
                                                       entries,
                                                       G_N_ELEMENTS (entries),
                                                       NULL);
-       tepl_action_map_add_action_entries_check_dups (G_ACTION_MAP (group),
+       amtk_action_map_add_action_entries_check_dups (G_ACTION_MAP (group),
                                                       entries,
                                                       G_N_ELEMENTS (entries),
                                                       NULL);
@@ -80,7 +80,7 @@ test_add_action_entries_check_dups__dups_in_array (void)
 
        group = g_simple_action_group_new ();
 
-       tepl_action_map_add_action_entries_check_dups (G_ACTION_MAP (group),
+       amtk_action_map_add_action_entries_check_dups (G_ACTION_MAP (group),
                                                       entries,
                                                       G_N_ELEMENTS (entries),
                                                       NULL);
@@ -88,9 +88,9 @@ test_add_action_entries_check_dups__dups_in_array (void)
        g_object_unref (group);
 }
 
-gint
-main (gint    argc,
-      gchar **argv)
+int
+main (int    argc,
+      char **argv)
 {
        g_test_init (&argc, &argv, NULL);
 
@@ -1,14 +1,14 @@
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
- * Tepl is free software; you can redistribute it and/or modify it under
+ * Amtk is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
@@ -1,14 +1,14 @@
  * option) any later version.
  *
- * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Amtk is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]